@@ -37,9 +37,9 @@ namespace KeePass.App
 		public static readonly Color ColorEditError = Color.FromArgb(255, 192, 192);
 
 		public const string XslFilesDir = "XSL";
-		public const string XslFileHtmlLite = "KDB4_DetailsLite.xsl";
-		public const string XslFileHtmlFull = "KDB4_DetailsFull.xsl";
-		public const string XslFileHtmlTabular = "KDB4_Tabular.xsl";
+		public const string XslFileHtmlLite = "KDBX_DetailsLite.xsl";
+		public const string XslFileHtmlFull = "KDBX_DetailsFull.xsl";
+		public const string XslFileHtmlTabular = "KDBX_Tabular.xsl";
 
 		public const string ShInstUtil = "ShInstUtil.exe";
 
@@ -111,6 +111,7 @@ namespace KeePass.App
 			public const string UserAccount = "useraccount";
 
 			public const string PasswordEncrypted = "pw-enc";
+			public const string PasswordStdIn = "pw-stdin";
 
 			public const string PreSelect = "preselect";
 
@@ -190,6 +191,19 @@ namespace KeePass.App
 			public static readonly Color LightYellow = Color.FromArgb(255, 255, 153);
 		}
 
+		public static class FileDialogContext
+		{
+			// Values must not contain '@'
+
+			public const string Database = "Database";
+			public const string Sync = "Sync";
+			public const string KeyFile = "KeyFile";
+			public const string Import = "Import";
+			public const string Export = "Export";
+			public const string Attachments = "Attachments";
+			public const string Xsl = "Xsl";
+		}
+
 		public const string DefaultTrlAuthor = "Dominik Reichl";
 		public const string DefaultTrlContact = @"http://www.dominik-reichl.de/";
 
