@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2011 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@ using System;
 using System.Collections.Generic;
 using System.ComponentModel;
 using System.Drawing;
+using System.Drawing.Drawing2D;
+using System.Drawing.Imaging;
 using System.Text;
 using System.Windows.Forms;
 using System.Diagnostics;
@@ -47,8 +49,8 @@ namespace KeePass.Forms
 		private bool m_bCreatingNew = false;
 		private IOConnectionInfo m_ioInfo = new IOConnectionInfo();
 
-		private SecureEdit m_secPassword = new SecureEdit();
-		private SecureEdit m_secRepeat = new SecureEdit();
+		private PwInputControlGroup m_icgPassword = new PwInputControlGroup();
+		private Image m_imgAccWarning = null;
 
 		public CompositeKey CompositeKey
 		{
@@ -86,19 +88,22 @@ namespace KeePass.Forms
 			FontUtil.AssignDefaultBold(m_cbKeyFile);
 			FontUtil.AssignDefaultBold(m_cbUserAccount);
 
+			Bitmap bmpBig = SystemIcons.Warning.ToBitmap();
+			m_imgAccWarning = UIUtil.CreateScaledImage(bmpBig, 16, 16);
+			bmpBig.Dispose();
+			m_picAccWarning.Image = m_imgAccWarning;
+
 			m_ttRect.SetToolTip(m_cbHidePassword, KPRes.TogglePasswordAsterisks);
 			m_ttRect.SetToolTip(m_btnSaveKeyFile, KPRes.KeyFileCreate);
 			m_ttRect.SetToolTip(m_btnOpenKeyFile, KPRes.KeyFileUseExisting);
+			m_ttRect.SetToolTip(m_tbRepeatPassword, KPRes.PasswordRepeatHint);
 
 			if(!m_bCreatingNew)
 				m_lblIntro.Text = KPRes.ChangeMasterKeyIntroShort;
 
-			m_secPassword.Attach(m_tbPassword, ProcessTextChangedPassword, true);
-			m_secRepeat.Attach(m_tbRepeatPassword, null, true);
-			m_cbHidePassword.Checked = true;
-
-			m_cbPassword.Checked = true;
-			ProcessTextChangedPassword(sender, e); // Update quality estimation
+			m_icgPassword.Attach(m_tbPassword, m_cbHidePassword, m_lblRepeatPassword,
+				m_tbRepeatPassword, m_lblEstimatedQuality, m_pbPasswordQuality,
+				m_lblQualityBits, this, true, false);
 
 			m_cmbKeyFile.Items.Add(KPRes.NoKeyFileSpecifiedMeta);
 			foreach(KeyProvider prov in Program.KeyProviderPool)
@@ -106,6 +111,7 @@ namespace KeePass.Forms
 
 			m_cmbKeyFile.SelectedIndex = 0;
 
+			m_cbPassword.Checked = true;
 			UIUtil.ApplyKeyUIFlags(Program.Config.UI.KeyCreationFlags,
 				m_cbPassword, m_cbKeyFile, m_cbUserAccount, m_cbHidePassword);
 
@@ -130,8 +136,14 @@ namespace KeePass.Forms
 
 		private void CleanUpEx()
 		{
-			m_secPassword.Detach();
-			m_secRepeat.Detach();
+			if(m_imgAccWarning != null)
+			{
+				m_picAccWarning.Image = null;
+				m_imgAccWarning.Dispose();
+				m_imgAccWarning = null;
+			}
+
+			m_icgPassword.Release();
 		}
 
 		private bool CreateCompositeKey()
@@ -140,13 +152,10 @@ namespace KeePass.Forms
 
 			if(m_cbPassword.Checked) // Use a password
 			{
-				if(m_secPassword.ContentsEqualTo(m_secRepeat) == false)
-				{
-					MessageService.ShowWarning(KPRes.PasswordRepeatFailed);
-					return false;
-				}
+				if(!m_icgPassword.ValidateData(true)) return false;
 
-				if(m_secPassword.TextLength == 0)
+				uint uPwLen = m_icgPassword.PasswordLength;
+				if(uPwLen == 0)
 				{
 					if(!MessageService.AskYesNo(KPRes.EmptyMasterPw +
 						MessageService.NewParagraph + KPRes.EmptyMasterPwHint +
@@ -158,7 +167,7 @@ namespace KeePass.Forms
 				}
 
 				uint uMinLen = Program.Config.Security.MasterPassword.MinimumLength;
-				if(m_secPassword.TextLength < uMinLen)
+				if(uPwLen < uMinLen)
 				{
 					string strML = KPRes.MasterPasswordMinLengthFailed;
 					strML = strML.Replace(@"{PARAM}", uMinLen.ToString());
@@ -166,7 +175,7 @@ namespace KeePass.Forms
 					return false;
 				}
 
-				byte[] pb = m_secPassword.ToUtf8();
+				byte[] pb = m_icgPassword.GetPasswordUtf8();
 
 				uint uMinQual = Program.Config.Security.MasterPassword.MinimumQuality;
 				if(QualityEstimation.EstimatePasswordBits(pb) < uMinQual)
@@ -207,7 +216,8 @@ namespace KeePass.Forms
 			else if(m_cbKeyFile.Checked && (!strKeyFile.Equals(KPRes.NoKeyFileSpecifiedMeta)) &&
 				(bIsKeyProv == true))
 			{
-				KeyProviderQueryContext ctxKP = new KeyProviderQueryContext(m_ioInfo, true);
+				KeyProviderQueryContext ctxKP = new KeyProviderQueryContext(
+					m_ioInfo, true, false);
 
 				bool bPerformHash;
 				byte[] pbCustomKey = Program.KeyProviderPool.GetKey(strKeyFile, ctxKP,
@@ -241,12 +251,7 @@ namespace KeePass.Forms
 
 		private void EnableUserControls()
 		{
-			m_tbPassword.Enabled = m_tbRepeatPassword.Enabled =
-				m_lblRepeatPassword.Enabled = m_lblQualityBits.Enabled =
-				m_lblEstimatedQuality.Enabled = m_cbPassword.Checked;
-			if((Program.Config.UI.KeyCreationFlags &
-				(ulong)AceKeyUIFlags.DisableHidePassword) == 0)
-				m_cbHidePassword.Enabled = m_cbPassword.Checked;
+			m_icgPassword.Enabled = m_cbPassword.Checked;
 
 			m_btnOpenKeyFile.Enabled = m_btnSaveKeyFile.Enabled =
 				m_cmbKeyFile.Enabled = m_cbKeyFile.Checked;
@@ -259,19 +264,9 @@ namespace KeePass.Forms
 				m_btnCreate.Enabled = false;
 			else m_btnCreate.Enabled = true;
 
-			SetHidePassword(m_cbHidePassword.Checked, false);
-
 			m_ttRect.SetToolTip(m_cmbKeyFile, strKeyFile);
 		}
 
-		private void SetHidePassword(bool bHide, bool bUpdateCheckBox)
-		{
-			if(bUpdateCheckBox) m_cbHidePassword.Checked = bHide;
-
-			m_secPassword.EnableProtection(bHide);
-			m_secRepeat.EnableProtection(bHide);
-		}
-
 		private void OnCheckedPassword(object sender, EventArgs e)
 		{
 			EnableUserControls();
@@ -284,19 +279,6 @@ namespace KeePass.Forms
 			EnableUserControls();
 		}
 
-		private void OnCheckedHidePassword(object sender, EventArgs e)
-		{
-			bool bHide = m_cbHidePassword.Checked;
-			if(!bHide && !AppPolicy.Try(AppPolicyId.UnhidePasswords))
-			{
-				m_cbHidePassword.Checked = true;
-				return;
-			}
-
-			SetHidePassword(bHide, false);
-			UIUtil.SetFocus(m_tbPassword, this);
-		}
-
 		private void OnBtnOK(object sender, EventArgs e)
 		{
 			if(!CreateCompositeKey()) this.DialogResult = DialogResult.None;
@@ -307,24 +289,12 @@ namespace KeePass.Forms
 			m_pKey = null;
 		}
 
-		private void ProcessTextChangedPassword(object sender, EventArgs e)
-		{
-			byte[] pbUTF8 = m_secPassword.ToUtf8();
-			uint uBits = QualityEstimation.EstimatePasswordBits(pbUTF8);
-			MemUtil.ZeroByteArray(pbUTF8);
-
-			m_lblQualityBits.Text = uBits.ToString() + " " + KPRes.Bits;
-			int iPos = (int)((100 * uBits) / (256 / 2));
-			if(iPos < 0) iPos = 0; else if(iPos > 100) iPos = 100;
-			m_pbPasswordQuality.Value = iPos;
-		}
-
 		private void OnClickKeyFileCreate(object sender, EventArgs e)
 		{
-			SaveFileDialog sfd = UIUtil.CreateSaveFileDialog(KPRes.KeyFileCreate,
+			SaveFileDialogEx sfd = UIUtil.CreateSaveFileDialog(KPRes.KeyFileCreate,
 				UrlUtil.StripExtension(UrlUtil.GetFileName(m_ioInfo.Path)) + "." +
 				AppDefs.FileExtension.KeyFile, UIUtil.CreateFileTypeFilter("key",
-				KPRes.KeyFiles, true), 1, "key", true);
+				KPRes.KeyFiles, true), 1, "key", AppDefs.FileDialogContext.KeyFile);
 
 			if(sfd.ShowDialog() == DialogResult.OK)
 			{
@@ -354,9 +324,9 @@ namespace KeePass.Forms
 
 		private void OnClickKeyFileBrowse(object sender, EventArgs e)
 		{
-			OpenFileDialog ofd = UIUtil.CreateOpenFileDialog(KPRes.KeyFileUseExisting,
+			OpenFileDialogEx ofd = UIUtil.CreateOpenFileDialog(KPRes.KeyFileUseExisting,
 				UIUtil.CreateFileTypeFilter("key", KPRes.KeyFiles, true), 2, null,
-				false, true);
+				false, AppDefs.FileDialogContext.KeyFile);
 
 			if(ofd.ShowDialog() == DialogResult.OK)
 			{
