@@ -238,9 +238,12 @@ namespace KeePass.UI
 			if(NativeLib.IsUnix())
 			{
 				AddAppByFile(AppLocator.FindAppUnix("epiphany-browser"), @"&Epiphany");
-				AddAppByFile(AppLocator.FindAppUnix("arora"), @"&Arora");
 				AddAppByFile(AppLocator.FindAppUnix("galeon"), @"Ga&leon");
 				AddAppByFile(AppLocator.FindAppUnix("konqueror"), @"&Konqueror");
+				AddAppByFile(AppLocator.FindAppUnix("rekonq"), @"&Rekonq");
+				AddAppByFile(AppLocator.FindAppUnix("arora"), @"&Arora");
+				AddAppByFile(AppLocator.FindAppUnix("midori"), @"&Midori");
+				AddAppByFile(AppLocator.FindAppUnix("Dooble"), @"&Dooble"); // Upper-case
 			}
 		}
 
@@ -254,22 +257,22 @@ namespace KeePass.UI
 
 		private void FindAppsByRegistryPriv(string strRootSubKey)
 		{
-			RegistryKey kRoot = Registry.LocalMachine.OpenSubKey(strRootSubKey);
+			RegistryKey kRoot = Registry.LocalMachine.OpenSubKey(strRootSubKey, false);
 			if(kRoot == null) return; // No assert, key might not exist
 			string[] vAppSubKeys = kRoot.GetSubKeyNames();
 
 			foreach(string strAppSubKey in vAppSubKeys)
 			{
-				RegistryKey kApp = kRoot.OpenSubKey(strAppSubKey);
+				RegistryKey kApp = kRoot.OpenSubKey(strAppSubKey, false);
 				string strName = (kApp.GetValue(string.Empty) as string);
 				string strAltName = null;
 
-				RegistryKey kCmd = kApp.OpenSubKey("shell\\open\\command");
+				RegistryKey kCmd = kApp.OpenSubKey("shell\\open\\command", false);
 				if(kCmd == null) { Debug.Assert(false); kApp.Close(); continue; }
 				string strCmdLine = (kCmd.GetValue(string.Empty) as string);
 				kCmd.Close();
 
-				RegistryKey kCaps = kApp.OpenSubKey("Capabilities");
+				RegistryKey kCaps = kApp.OpenSubKey("Capabilities", false);
 				if(kCaps != null)
 				{
 					strAltName = (kCaps.GetValue("ApplicationName") as string);
