@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2011 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -331,7 +331,7 @@ namespace KeePass.UI
 		public void SetPassword(byte[] pbUtf8)
 		{
 			Debug.Assert(pbUtf8 != null);
-			if(pbUtf8 == null) throw new ArgumentNullException("pbUTF8");
+			if(pbUtf8 == null) throw new ArgumentNullException("pbUtf8");
 
 			if(m_secString != null)
 			{
