@@ -201,7 +201,8 @@ namespace KeePass.Util
 
 		private static string GetMutexPath(string strName)
 		{
-			string strDir = UrlUtil.EnsureTerminatingSeparator(Path.GetTempPath(), false);
+			string strDir = UrlUtil.EnsureTerminatingSeparator(
+				UrlUtil.GetTempPath(), false);
 			return (strDir + IpcUtilEx.IpcMsgFilePreID + IpcBroadcast.GetUserID() +
 				"-Mutex-" + strName + ".tmp");
 		}
